|pypi| |travis| |codecov| |downloads|

edc-pharmacy
------------

.. |pypi| image:: https://img.shields.io/pypi/v/edc-pharmacy.svg
    :target: https://pypi.python.org/pypi/edc-pharmacy

.. |travis| image:: https://travis-ci.com/clinicedc/edc-pharmacy.svg?branch=develop
    :target: https://travis-ci.com/clinicedc/edc-pharmacy

.. |codecov| image:: https://codecov.io/gh/clinicedc/edc-pharmacy/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/clinicedc/edc-pharmacy

.. |downloads| image:: https://pepy.tech/badge/edc-pharmacy
   :target: https://pepy.tech/project/edc-pharmacy
